AppliedId

Struct AppliedId 

pub struct AppliedId {
    pub id: Id,
    pub m: SlotMap,
}
AppliedIds are invocations of e-classes.

Recall that in slotted egraphs, e-classes have arguments - and in order to talk about the set of terms in an e-class, you always need to invocate your e-class using a bunch of arguments. This “invocation” is what an AppliedId represents. The Id part identifies an e-class, and the SlotMap is used to map the argument-slots of the e-class to the values that you put into them.

Fields

id: Idm: SlotMap

Implementations

Source

impl AppliedId

pub fn new(id: Id, m: SlotMap) -> Self

pub fn apply_slotmap(&self, m: &SlotMap) -> AppliedId

pub fn apply_slotmap_partial(&self, m: &SlotMap) -> AppliedId

pub fn apply_slotmap_fresh(&self, m: &SlotMap) -> AppliedId

pub fn slots(&self) -> SmallHashSet<Slot>

pub fn slots_mut(&mut self) -> Vec<&mut Slot>

pub fn null() -> Self