RewriteT

Struct RewriteT 

pub struct RewriteT<L: Language, N: Analysis<L> = (), T: Any = ()> {
    pub searcher: Box<dyn Fn(&EGraph<L, N>) -> T>,
    pub applier: Box<dyn Fn(T, &mut EGraph<L, N>)>,
}
Use this type when you want to build your own Rewrite.

The type parameter T can be anything you want, as long as the searcher creates it, and the applier consumes it.

In most cases, T is a Subst.

Fields

searcher: Box<dyn Fn(&EGraph<L, N>) -> T>applier: Box<dyn Fn(T, &mut EGraph<L, N>)>

Implementations

Source

impl<L: Language + 'static, N: Analysis<L> + 'static, T: 'static> RewriteT<L, N, T>

pub fn into(self) -> Rewrite<L, N>

Use this function to convert it to an actual Rewrite.