ProgressMeasure

Struct ProgressMeasure 

pub struct ProgressMeasure {
    pub number_of_classes: usize,
    pub number_of_live_classes: usize,
    pub sum_of_slots: usize,
    pub sum_of_symmetries: usize,
}
A Progress Measure to check saturation of an e-graph with.

Fields

number_of_classes: usize

How many classes that were allocated in this e-graph. This measure is strictly growing.

number_of_live_classes: usize

How many classes are still “live”. If “number_of_classes” isn’t changed, this can only decrease (by union).

sum_of_slots: usize

How many parameter-slots are still in the e-classes. If number_of_classes & number_of_live_classes isn’t changed, this can only decrease (by proving a redundancy by union).

sum_of_symmetries: usize

How many symmetries the egraphs knows. If number_of_classes & number_of_live_classes & sum_of_slots isn’t changed, this can only increase (by proving a symmetry by union).